%global momorel 1

Summary: Validating, recursive, and caching DNS(SEC) resolver
Name: unbound
Version: 1.3.4
Release: %{momorel}m%{?dist}
License: BSD
Url: http://unbound.net/
#Url: http://www.nlnetlabs.nl/unbound/
Source0: http://unbound.net/downloads/%{name}-%{version}.tar.gz
NoSource: 0
Source1: unbound.init
Source2: unbound.conf
Source3: unbound.munin
Patch4: unbound-1.2-glob.patch

Group: System Environment/Daemons
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: flex, openssl-devel >= 0.9.8g-12, ldns-devel >= 1.5.0, 
BuildRequires: libevent-devel >= 1.4.5
Requires(post): chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts
Requires(postun): initscripts
Requires: ldns >= 1.5.0, dnssec-conf >= 1.19
Requires(pre): shadow-utils

%description
Unbound is a validating, recursive, and caching DNS(SEC) resolver.

The C implementation of Unbound is developed and maintained by NLnet
Labs. It is based on ideas and algorithms taken from a java prototype
developed by Verisign labs, Nominet, Kirei and ep.net.

Unbound is designed as a set of modular components, so that also
DNSSEC (secure DNS) validation and stub-resolvers (that do not run
as a server, but are linked into an application) are easily possible.

%package munin
Summary: Plugin for the munin / munin-node monitoring package
Group:     System Environment/Daemons
Requires: munin-node
Requires: %{name} = %{version}-%{release}, bc

%description munin
Plugin for the munin / munin-node monitoring package

%package devel
Summary: Development package that includes the unbound header files
Group: Development/Libraries
Requires: %{name}-libs = %{version}-%{release}, openssl-devel, ldns-devel

%description devel
The devel package contains the unbound library and the include files

%package libs
Summary: Libraries used by the unbound server and client applications
Group: Applications/System
Requires(post): /sbin/ldconfig
Requires(postun): /sbin/ldconfig
Requires: openssl >= 0.9.8g-12

%description libs
Contains libraries used by the unbound server and client applications


%prep
%setup -q
%patch4 -p1

%build
%configure  --with-ldns= --with-libevent --with-pthreads --with-ssl \
            --disable-rpath --enable-debug --disable-static \
            --with-conf-file=%{_sysconfdir}/%{name}/unbound.conf \
            --with-pidfile=%{_localstatedir}/run/%{name}/%{name}.pid \
	    --enable-sha2 
%{__make} CFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE" QUIET=no %{?_smp_mflags}

%install
rm -rf %{buildroot}
%{__make} DESTDIR=%{buildroot} install
install -d 0755 %{buildroot}%{_initscriptdir}
install -m 0755 %{SOURCE1} %{buildroot}%{_initscriptdir}/unbound
install -m 0755 %{SOURCE2} %{buildroot}%{_sysconfdir}/unbound
# Install munin plugin and its softlinks
install -d 0755 %{buildroot}%{_sysconfdir}/munin/plugin-conf.d
install -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/munin/plugin-conf.d/unbound
install -d 0755 %{buildroot}%{_datadir}/munin/plugins/
install -m 0755 contrib/unbound_munin_ %{buildroot}%{_datadir}/munin/plugins/unbound
for plugin in unbound_munin_hits unbound_munin_queue unbound_munin_memory unbound_munin_by_type unbound_munin_by_class unbound_munin_by_opcode unbound_munin_by_rcode unbound_munin_by_flags unbound_munin_histogram; do
    ln -s unbound %{buildroot}%{_datadir}/munin/plugins/$plugin
done 

# remove static library from install (fedora packaging guidelines)
rm -rf %{buildroot}%{_libdir}/*.la

mkdir -p %{buildroot}%{_localstatedir}/run/unbound


%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc doc/README doc/CREDITS doc/LICENSE doc/FEATURES
%attr(0755,root,root) %{_initscriptdir}/%{name}
%attr(0755,root,root) %dir %{_sysconfdir}/%{name}
%attr(0755,unbound,unbound) %dir %{_localstatedir}/run/%{name}
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}/unbound.conf
%{_sbindir}/*
%{_mandir}/*/*

%files munin
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/munin/plugin-conf.d/unbound
%{_datadir}/munin/plugins/unbound*

%files devel
%defattr(-,root,root,-)
%{_libdir}/libunbound.so
%{_includedir}/unbound.h
%doc README

%files libs
%defattr(-,root,root,-)
%{_libdir}/libunbound.so.*
%doc doc/README doc/LICENSE


%pre
getent group unbound >/dev/null || groupadd -r unbound
getent passwd unbound >/dev/null || \
useradd -r -g unbound -d %{_sysconfdir}/unbound -s /sbin/nologin \
-c "Unbound DNS resolver" unbound
exit 0

%post
/sbin/chkconfig --add %{name}
# Check DNSSEC settings if this is a fresh install
if [ "$1" -eq 1 ]; then
  if [ -r /etc/sysconfig/dnssec ]; then
    . /etc/sysconfig/dnssec
    [ -x /usr/sbin/dnssec-configure ] && \
      dnssec-configure -u --norestart --nocheck --dnssec="$DNSSEC" --dlv="$DLV" > \
        /dev/null 2>&1
  fi;
fi

%post libs -p /sbin/ldconfig

%preun
if [ "$1" -eq 0 ]; then
        /sbin/service %{name} stop >/dev/null 2>&1
        /sbin/chkconfig --del %{name} 
fi

%postun
if [ "$1" -ge "1" ]; then
  /sbin/service %{name} condrestart >/dev/null 2>&1 || :
fi

%postun libs -p /sbin/ldconfig

%changelog
* Tue Oct 13 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.3.4-1m)
- [SECURITY] CVE-2009-3602
- update to 1.3.4

* Thu Aug  6 2009 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.3.3-1m)
- update to 1.3.3

* Wed Jul 15 2009 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.3.2-1m)
- update to 1.3.2

* Tue Jun 30 2009 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.3.0-1m)
- update to 1.3.0
- add Patch1: unbound-r1657.patch, Patch2: unbound-r1670.patch from fedora
- add Patch3: unbound-r1677.patch, Patch4: unbound-1.2-glob.patch from fedora

* Tue Apr 07 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.2.1-2m)
- rebuild against openssl-0.9.8k

* Thu Feb 12 2009 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.2.1-1m)
- update to 1.2.1

* Tue Feb  3 2009 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.2.0-3m)
- rebuild against ldns-1.4.0
- merge fedora 1.2.0-2 spec
- add Source2: unbound.conf
- add Source3: unbound.munin
- separate sub packages: munin, devel and libs

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.2.0-2m)
- rebuild against rpm-4.6

* Thu Jan 15 2009 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.2.0-1m)
- update to 1.2.0

* Wed Nov 26 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.1.1-1m)
- update to 1.1.1

* Wed Sep 10 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.0.2-1m)
- update to 1.0.2

* Sat Jul 19 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.0.1-1m)
- update to 1.0.1

* Wed May 28 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.0.0-2m)
- move configure from befor %%build section to after

* Sat May 24 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.0.0-1m)
- update to 1.0.0
- this spec file came from unbound-1.0.0/contrib/unbound.spec
- use %%{_initscriptdir} instead of %%{_initrddir}
- add "--with-ldns=" in configure for use external ldns
- delete "--disable-static", this option cause build error

* Thu Apr 25 2008 Wouter Wijngaards <wouter@nlnetlabs.nl> - 0.12
- Using parts from ports collection entry by Jaap Akkerhuis.
- Using Fedoraproject wiki guidelines.

* Wed Apr 23 2008 Wouter Wijngaards <wouter@nlnetlabs.nl> - 0.11
- Initial version.
